@@ -48,6 +48,7 @@ my %hierarchy = (
     'FormatScheme' => 'ResourceBase',
     'GradientFill' => 'FillFormat',
     'HeaderFooter' => 'ResourceBase',
+    'Html5ExportOptions' => 'ExportOptions',
     'HtmlExportOptions' => 'ExportOptions',
     'Image' => 'ResourceBase',
     'ImageExportOptions' => 'ExportOptions',
@@ -136,6 +137,7 @@ my %determiners = (
     'Axes' => {  },
     'Axis' => {  },
     'BlurEffect' => {  },
+    'Camera' => {  },
     'ChartCategory' => {  },
     'ChartTitle' => {  },
     'ChartWall' => {  },
@@ -165,6 +167,7 @@ my %determiners = (
     'InputFile' => {  },
     'InteractiveSequence' => {  },
     'Legend' => {  },
+    'LightRig' => {  },
     'LineFormat' => {  },
     'MergingSource' => {  },
     'NormalViewRestoredProperties' => {  },
@@ -183,6 +186,7 @@ my %determiners = (
     'ResourceUri' => {  },
     'Series' => {  },
     'SeriesMarker' => {  },
+    'ShapeBevel' => {  },
     'ShapeExportFormat' => {  },
     'ShapeImageExportOptions' => {  },
     'ShapeThumbnailBounds' => {  },
@@ -199,6 +203,7 @@ my %determiners = (
     'TableRow' => {  },
     'Task' => {  },
     'TextItem' => {  },
+    'ThreeDFormat' => {  },
     'AddLayoutSlide' => { 'Type' => 'AddLayoutSlide', },
     'AddMasterSlide' => { 'Type' => 'AddMasterSlide', },
     'AddShape' => { 'Type' => 'AddShape', },
@@ -214,6 +219,7 @@ my %determiners = (
     'FormatScheme' => {  },
     'GradientFill' => { 'Type' => 'Gradient', },
     'HeaderFooter' => {  },
+    'Html5ExportOptions' => { 'Format' => 'html5', },
     'HtmlExportOptions' => { 'Format' => 'html', },
     'Image' => {  },
     'ImageExportOptions' => { 'Format' => 'image', },
